@@ -4,7 +4,7 @@ import os
 import subprocess
 import sys
 
-__version__ = '0.4.1'
+from .__version__ import __version__
 
 # must have shell = True on Windows
 shellout = sys.platform == 'win32'
@@ -42,7 +42,7 @@ class Runner(object):
         for env_path in env_paths:
             with open(env_path, 'r') as env_file:
                 root, name = os.path.split(env_path)
-                value = env_file.read().strip()
+                value = env_file.read().strip().replace('\x00', '\n')
                 yield name, value
 
     def path(self, path):
@@ -50,6 +50,9 @@ class Runner(object):
         if not os.path.exists(real_path):
             # use 111 error code to adher to envdir's standard
             self.parser.error("envdir %r does not exist" % path, no=111)
+        if not os.path.isdir(real_path):
+            # use 111 error code to adher to envdir's standard
+            self.parser.error("envdir %r not a directory" % path, no=111)
         return real_path
 
     def read(self, path=None):
